# -*- coding: utf-8 -*-
# @author: leesoar

"""postcard"""

MAIL_ADDR = {
    "tom": "pop.tom.com",
    "gmail": "pop.gmail.com",
    "yahoo": "pop.mail.yahoo.com",
    "china": "pop.china.com",
    "21cn": "pop.21cn.com",
    "163": "pop.163.com",
    "126": "pop.126.com",
    "qq": "pop.qq.com",
    "sina": "pop3.sina.com.cn",
}
