# -*- coding: utf-8 -*-
# @author: leesoar
# @email: secure@tom.com
# @email2: employ@aliyun.com

import argparse

from postcard import __version__

parser = argparse.ArgumentParser(description=f"postcard", prog="postcard", add_help=False)
parser.add_argument('-v', '--version', action='version', version=__version__, help='Get version of postcard')
parser.add_argument('-h', '--help', action='help', help='Show help message')
parser.parse_args()


def run():
    return "Powered by leesoar.com"
